@@ -73,7 +73,8 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
     # Create Company years column
     df = devutils.create_company_years_column( df=df )
 
-    df = devutils.create_new_position_flag(df=df, days=90)
+    for days in config['days_to_define_new_position']:
+        df = devutils.create_new_position_flag(df=df, days=days)
 
     # Create new seniorities and the rest go to "other"
     df = devutils.fill_seniority_column( df=df )
