@@ -176,12 +176,16 @@ def set_idemailstatus_target_column(df):
         df = df[~df['IDEmailStatus'].isin([3, 5, 7, 32])]
         df.loc[df['IDEmailStatus'] != 14, 'IDEmailStatus'] = 0
         df.loc[df['IDEmailStatus'] == 14, 'IDEmailStatus'] = 1
+        date_col = df['campaign_bulk_date']
+        df.drop( labels=['campaign_bulk_date'], axis=1, inplace=True )
+        df.insert(loc=0, value=date_col, column= 'campaign_bulk_date')
         status_col = df['IDEmailStatus']
         df.drop( labels=['IDEmailStatus'], axis=1, inplace=True )
-        df.insert(loc=0, value=status_col, column= 'IDEmailStatus')
+        df.insert(loc=1, value=status_col, column= 'IDEmailStatus')
         bv_col = df['BV']
         df.drop( labels=['BV'], axis=1, inplace=True )
-        df.insert( loc=1, value=bv_col, column='BV' )
+        df.insert( loc=2, value=bv_col, column='BV' )
+
     else:
         logger.error('No IDEmailSTatus column found')
         raise Exception('No IDEmailStatus column found!!!!!')
@@ -193,12 +197,15 @@ def set_bv_target_column(df):
         logger.info('Setting BV status target ')
         df = df[df.BV.notna()]
         df['BV']=df['BV'].astype('float32')
-        bv_col = df['BV']
-        df.drop( labels=['BV'], axis=1, inplace=True )
-        df.insert( loc=0, value=bv_col, column='BV' )
+        date_col = df['campaign_bulk_date']
+        df.drop( labels=['campaign_bulk_date'], axis=1, inplace=True )
+        df.insert(loc=0, value=date_col, column= 'campaign_bulk_date')
         status_col = df['IDEmailStatus']
         df.drop( labels=['IDEmailStatus'], axis=1, inplace=True )
         df.insert(loc=1, value=status_col, column= 'IDEmailStatus')
+        bv_col = df['BV']
+        df.drop( labels=['BV'], axis=1, inplace=True )
+        df.insert( loc=2, value=bv_col, column='BV' )
 
     else:
         logger.error('No BV column found')
